==> kwallet-pam-5.19.90.tar.xz: kwallet-pam-5.19.90/pam_kwallet_init.desktop.cmake <==
[Desktop Entry]
Name=KWallet PAM Socket Connection
Name[ca]=Connexió a sòcol PAM del KWallet
Name[ca@valencia]=Connexió al sòcol PAM de KWallet
Name[cs]=Připojení Socketu Kwallet PAM
Name[da]=KWallet PAM-sokkel-forbindelse
Name[de]=Verbindung zu KWallet-PAM-Socket
Name[el]=Σύνδεση υποδοχής KWallet PAM
Name[en_GB]=KWallet PAM Socket Connection
Name[es]=Conexión con el «socket» PAM de KWallet
Name[et]=KDE turvalaeka PAM-sokli ühendus
Name[eu]=KWallet PAM socket konexioa
Name[fi]=KWalletin PAM-pistokeyhteys
Name[fr]=Connection au socket PAM de KWallet
Name[gl]=Conexión ao sócket PAM de KWallet
Name[hi]=के-वालेट पीएएम सोकेट कनेक्शन
Name[hu]=KWallet PAM socket-kapcsolat
Name[ia]=Connexion de PAM Socket de KWallet
Name[id]=KWallet PAM Socket Connection
Name[it]=Connessione socket PAM di KWallet
Name[ko]=KWallet PAM 소켓 연결
Name[lt]=KWallet PAM lizdo ryšys
Name[nl]=KWallet verbinding met PAM-socket
Name[nn]=KWallet PAM-socket-tilkopling
Name[pa]=ਕੇ-ਵਾਲਿਟ PAM ਸਾਕਟ ਕਨੈਕਸ਼ਨ
Name[pl]=Połączenie do gniazda PAM KPortfela
Name[pt]=Ligação por 'Socket' entre PAM e o KWallet
Name[pt_BR]=Conexão do Socket PAM do KWallet
Name[ru]=Интеграция KWallet и PAM
Name[sk]=Pripojenie socketu KWallet PAM
Name[sl]=Povezava z vtičem PAM KWalleta
Name[sr]=Веза са К‑новчаниковим ПАМ сокетом
Name[sr@ijekavian]=Веза са К‑новчаниковим ПАМ сокетом
Name[sr@ijekavianlatin]=Veza sa K‑novčanikovim PAM soketom
Name[sr@latin]=Veza sa K‑novčanikovim PAM soketom
Name[sv]=Plånbokens PAM-uttagsanslutning
Name[tg]=Пайвасти бастагоҳи KWallet PAM
Name[tr]=KWallet PAM Soketi Bağlantısı
Name[uk]=З’єднання із сокетом PAM KWallet
Name[x-test]=xxKWallet PAM Socket Connectionxx
Name[zh_CN]=KWallet PAM 套接字连接
Name[zh_TW]=KWallet PAM Socket 連線
Comment=Connect to KWallet PAM socket
Comment[ca]=Connecta a un sòcol PAM del KWallet
Comment[ca@valencia]=Connecta a un sòcol PAM de KWallet
Comment[cs]=Připojit k socketu Kwallet PAM
Comment[da]=Forbind til KWallet PAM-sokkel
Comment[de]=Zum KWallet-PAM-Socket verbinden
Comment[el]=Σύνδεση με υποδοχή KWallet PAM
Comment[en_GB]=Connect to KWallet PAM socket
Comment[es]=Conectar con el «socket» PAM de KWallet
Comment[et]=Ühendumine KDE turvalaeka PAM-sokliga
Comment[eu]=Konektatu KWallet-en PAM socket-era
Comment[fi]=Yhteys KWalletin PAM-pistokkeeseen
Comment[fr]=Connecter au socket PAM de KWallet
Comment[gl]=Conectar ao sócket PAM de KWallet
Comment[hi]=के-वालेट पीएएम सोकेट से संपर्क जोडें
Comment[hu]=Kapcsolódás KWallet PAM sockethez
Comment[ia]=Connecte a PAMsoccket de KWallet
Comment[id]=Koneksikan ke soket KWallet PAM
Comment[it]=Connetti al socket PAM di KWallet
Comment[ko]=KWallet PAM 소켓에 연결할 수 없음
Comment[lt]=Prisijungti prie KWallet PAM lizdo
Comment[nl]=Verbinden met KWallet PAM-socket
Comment[nn]=Kopla til KWallet PAM-socket
Comment[pa]=ਕੇ-ਵਾਲਿਟ PAM ਸਾਕਟ ਨਾਲ ਕਨੈਕਟ ਕਰੋ
Comment[pl]=Połącz z gniazdem PAM KPortfela
Comment[pt]=Ligar ao 'socket' de PAM do KWallet
Comment[pt_BR]=Conecta ao socket PAM do KWallet
Comment[ru]=Подключение PAM к KWallet по сокету
Comment[sk]=Pripojiť na KWallet PAM socket
Comment[sl]=Povežite se z vtičem PAM KWalleta
Comment[sr]=Повежи се на К‑новчаников ПАМ сокет
Comment[sr@ijekavian]=Повежи се на К‑новчаников ПАМ сокет
Comment[sr@ijekavianlatin]=Poveži se na K‑novčanikov PAM soket
Comment[sr@latin]=Poveži se na K‑novčanikov PAM soket
Comment[sv]=Anslut till plånbokens PAM-uttag
Comment[tg]=Пайваст шудан ба бастагоҳи KWallet PAM
Comment[tr]=KWallet PAM soketine bağlan
Comment[uk]=З’єднатися із сокетом PAM KWallet
Comment[x-test]=xxConnect to KWallet PAM socketxx
Comment[zh_CN]=连接到 KWallet PAM 套接字
Comment[zh_TW]=連線到 KWallet PAM socket
Exec=${CMAKE_INSTALL_FULL_LIBEXECDIR}/pam_kwallet_init
Type=Application
NoDisplay=true
X-KDE-StartupNotify=false
X-KDE-autostart-phase=0

==> kwallet-pam-5.20.1.tar.xz: kwallet-pam-5.20.1/pam_kwallet_init.desktop.cmake <==
[Desktop Entry]
Name=KWallet PAM Socket Connection
Name[ca]=Connexió a sòcol PAM del KWallet
Name[ca@valencia]=Connexió al sòcol PAM de KWallet
Name[cs]=Připojení Socketu Kwallet PAM
Name[da]=KWallet PAM-sokkel-forbindelse
Name[de]=Verbindung zu KWallet-PAM-Socket
Name[el]=Σύνδεση υποδοχής KWallet PAM
Name[en_GB]=KWallet PAM Socket Connection
Name[es]=Conexión con el «socket» PAM de KWallet
Name[et]=KDE turvalaeka PAM-sokli ühendus
Name[eu]=KWallet PAM socket konexioa
Name[fi]=KWalletin PAM-pistokeyhteys
Name[fr]=Connection au socket PAM de KWallet
Name[gl]=Conexión ao sócket PAM de KWallet
Name[hi]=के-वालेट पीएएम सोकेट कनेक्शन
Name[hu]=KWallet PAM socket-kapcsolat
Name[ia]=Connexion de PAM Socket de KWallet
Name[id]=KWallet PAM Socket Connection
Name[it]=Connessione socket PAM di KWallet
Name[ko]=KWallet PAM 소켓 연결
Name[lt]=KWallet PAM lizdo ryšys
Name[nl]=KWallet verbinding met PAM-socket
Name[nn]=KWallet PAM-socket-tilkopling
Name[pa]=ਕੇ-ਵਾਲਿਟ PAM ਸਾਕਟ ਕਨੈਕਸ਼ਨ
Name[pl]=Połączenie do gniazda PAM KPortfela
Name[pt]=Ligação por 'Socket' entre PAM e o KWallet
Name[pt_BR]=Conexão do Socket PAM do KWallet
Name[ro]=Conexiune la soclu PAM KWallet
Name[ru]=Интеграция KWallet и PAM
Name[sk]=Pripojenie socketu KWallet PAM
Name[sl]=Povezava z vtičem PAM KWalleta
Name[sr]=Веза са К‑новчаниковим ПАМ сокетом
Name[sr@ijekavian]=Веза са К‑новчаниковим ПАМ сокетом
Name[sr@ijekavianlatin]=Veza sa K‑novčanikovim PAM soketom
Name[sr@latin]=Veza sa K‑novčanikovim PAM soketom
Name[tg]=Пайвасти бастагоҳи KWallet PAM
Name[tr]=KWallet PAM Soketi Bağlantısı
Name[uk]=З’єднання із сокетом PAM KWallet
Name[x-test]=xxKWallet PAM Socket Connectionxx
Name[zh_CN]=KWallet PAM 套接字连接
Name[zh_TW]=KWallet PAM Socket 連線
Comment=Connect to KWallet PAM socket
Comment[ca]=Connecta a un sòcol PAM del KWallet
Comment[ca@valencia]=Connecta a un sòcol PAM de KWallet
Comment[cs]=Připojit k socketu Kwallet PAM
Comment[da]=Forbind til KWallet PAM-sokkel
Comment[de]=Zum KWallet-PAM-Socket verbinden
Comment[el]=Σύνδεση με υποδοχή KWallet PAM
Comment[en_GB]=Connect to KWallet PAM socket
Comment[es]=Conectar con el «socket» PAM de KWallet
Comment[et]=Ühendumine KDE turvalaeka PAM-sokliga
Comment[eu]=Konektatu KWallet-en PAM socket-era
Comment[fi]=Yhteys KWalletin PAM-pistokkeeseen
Comment[fr]=Connecter au socket PAM de KWallet
Comment[gl]=Conectar ao sócket PAM de KWallet
Comment[hi]=के-वालेट पीएएम सोकेट से संपर्क जोडें
Comment[hu]=Kapcsolódás KWallet PAM sockethez
Comment[ia]=Connecte a PAMsoccket de KWallet
Comment[id]=Koneksikan ke soket KWallet PAM
Comment[it]=Connetti al socket PAM di KWallet
Comment[ko]=KWallet PAM 소켓에 연결할 수 없음
Comment[lt]=Prisijungti prie KWallet PAM lizdo
Comment[nl]=Verbinden met KWallet PAM-socket
Comment[nn]=Kopla til KWallet PAM-socket
Comment[pa]=ਕੇ-ਵਾਲਿਟ PAM ਸਾਕਟ ਨਾਲ ਕਨੈਕਟ ਕਰੋ
Comment[pl]=Połącz z gniazdem PAM KPortfela
Comment[pt]=Ligar ao 'socket' de PAM do KWallet
Comment[pt_BR]=Conecta ao socket PAM do KWallet
Comment[ro]=Conectează la soclul PAM KWallet
Comment[ru]=Подключение PAM к KWallet по сокету
Comment[sk]=Pripojiť na KWallet PAM socket
Comment[sl]=Povežite se z vtičem PAM KWalleta
Comment[sr]=Повежи се на К‑новчаников ПАМ сокет
Comment[sr@ijekavian]=Повежи се на К‑новчаников ПАМ сокет
Comment[sr@ijekavianlatin]=Poveži se na K‑novčanikov PAM soket
Comment[sr@latin]=Poveži se na K‑novčanikov PAM soket
Comment[tg]=Пайваст шудан ба бастагоҳи KWallet PAM
Comment[tr]=KWallet PAM soketine bağlan
Comment[uk]=З’єднатися із сокетом PAM KWallet
Comment[x-test]=xxConnect to KWallet PAM socketxx
Comment[zh_CN]=连接到 KWallet PAM 套接字
Comment[zh_TW]=連線到 KWallet PAM socket
Exec=${CMAKE_INSTALL_FULL_LIBEXECDIR}/pam_kwallet_init
Type=Application
NoDisplay=true
X-KDE-StartupNotify=false
X-KDE-autostart-phase=0
